<template>
  <view>
    <view class="my-tab-warp" :class="[`my-tab-${type}`]">
      <text class="my-tab-text" @click="clickTab">{{text}}</text>
      <view 
        v-if="closeable" 
        @click="close" 
        class="iconfont my-tab-close"
      >
		<text v-if="type == 'error'">&#xe6ea;</text>
		<text v-else-if="type == 'primary'">&#xe7f9;</text>
		<text v-else-if="type == 'success'">&#xe7fa;</text>
		<text v-else-if="type == 'warning'">&#xe7fb;</text>
	  </view>
    </view>
  </view>
</template>

<script>
export default {
  name: "my-tag",
  props: {
    text: {
      type: String
    },
	// 关闭、点击时的回传参数
    index: {
      type: Number
    },
    closeable: {
      type: Boolean,
      default: true
    },
    type: {
      type: String,
      default: 'error',
      validator: (value) => ['primary', 'success', 'error', 'warning'].includes(value)
    }
  },
  methods: {
    close() {
      this.$emit('close', this.index)
    },
	clickTab() {
	  this.$emit('click', this.index)
	}
  }
}
</script>

<style>
.my-tab-warp {
  display: inline-flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  height: 22px;
  line-height: 22px;
  border-radius: 3px;
  padding: 0 8px;
  font-size: 12px;
  margin-right: 3px;
  border: 1px solid;
}

.my-tab-text {
  color: inherit;
}

.my-tab-close {
  font-size: 12px !important;
  margin-left: 4px;
  cursor: pointer;
}

/* 不同类型样式 */
.my-tab-primary {
  color: #2d8cf0;
  border-color: #2d8cf0;
  background-color: rgba(45, 140, 240, 0.1);
}

.my-tab-success {
  color: #19be6b;
  border-color: #19be6b;
  background-color: rgba(25, 190, 107, 0.1);
}

.my-tab-error {
  color: #ed4014;
  border-color: #ed4014;
  background-color: rgba(237, 64, 20, 0.1);
}

.my-tab-warning {
  color: #ff9900;
  border-color: #ff9900;
  background-color: rgba(255, 153, 0, 0.1);
}
</style>